@@ -8,16 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.core._jsii
-import aws_cdk.cx_api._jsii
-import aws_cdk.pipelines._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-pipelines-github",
-    "0.0.59",
+    "0.0.61",
     __name__[0:-6],
-    "cdk-pipelines-github@0.0.59.jsii.tgz",
+    "cdk-pipelines-github@0.0.61.jsii.tgz",
 )
 
 __all__ = [
